
============================
Contributing to Pulsar
============================

* Help improving documentation: typo corrections, error fixes and better
  explanations through clearer writing and more examples.
* Join the `pulsar mailing list`_ and post or answer questions.
* Fork the project on github.
* Write about pulsar.


Using with Sphinx
====================

Pulsar's documentation uses Sphinx_


.. _`pulsar mailing list`: https://groups.google.com/forum/?fromgroups=#!forum/python-pulsar
.. _Sphinx: http://sphinx-doc.org/